# The utils module

This module contains some utility functions/classes that are directly written in Python. Every `object` described here is contained in the same module and can be accessed as `baggianalysis.utils.object`.

```eval_rst
.. toctree::
   :maxdepth: 2

.. currentmodule:: baggianalysis.utils

.. autosummary::
    :nosignatures:

    print_bondfile
    print_detailed_polymer_topology
    
.. autofunction:: print_bondfile
.. autofunction:: print_detailed_polymer_topology
    
```